# Algefunc
A small demo library for studying libraries in python

### Installation
```
pip install algefunc
```

### Get started
How to work with a function of first degree with this lib:

```Python
from algefunc import func

# Instantiate a variable
functiontest = func('4x-8')

# Print the variable
print(functiontest)

# Output: 2.0
```